@@ -40,8 +40,13 @@ def host_output(args):
     tags_fields = args.resource.get("tags")
     values_fields = args.resource.get("values")
     values_transform = args.resource.get("values_transform")
+    try:
+       values = list_adress.get()
+    except routeros_api.exceptions.RouterOsApiConnectionError as e:
+        log.debug(e)
+        return
 
-    for address in list_adress.get():
+    for address in values:
         extra_values = []
         tag_values = [("router_name", args.host)]
 
@@ -179,7 +184,7 @@ def get_router_data(args, host, q):
     for resource in resources:
         args.host = host
         args.resource = resource
-        if not args.ignore_interval and not args.daemon:
+        if not args.ignore_interval and args.daemon:
             resource_path = resource.get("path")
             resource_interval_millis = resource.get("interval", 60) * 1000
             last_resource_run_key = "{}_{}".format(host.replace(".", "_"), resource_path.replace("/", "_"))
@@ -192,9 +197,11 @@ def get_router_data(args, host, q):
                 continue
             last_resouce_run_dict[last_resource_run_key] = current_milli_sec
         values = host_output(args)
-        if not q.full():
-            q.put(values)
-        router_values.append(values)
+        log.debug(values)
+        if values:
+            if not q.full():
+                q.put(values)
+            router_values.append(values)
     return router_values
 
 
